@@ -2,7 +2,7 @@
 
 // fixg2sxd - a utility to convert fig to sxd format
 
-// Copyright (C) 2003-2006 Alexander Bürger, acfb@users.sourceforge.net
+// Copyright (C) 2003-2007 Alexander Bürger, acfb@users.sourceforge.net
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -24,6 +24,7 @@
 #include "xmlwrite.h"
 #include "zipwrite.h"
 
+#include <cstdlib>
 #include <string>
 #include <iostream>
 #include <fstream>
@@ -409,7 +410,7 @@ static void usage( const char* cmdname, bool err=true )
         << "can be set (in cm), e.g. to 0 to have fine lines." << endl << endl
         << "With -w files with out-of-specification values will be accepted," <<endl
         << "but a warning will be printed and the bad values sanitized." << endl << endl
-        << "This is fig2sxd version 0.16. (C) 2003-2006 Alexander Bürger."
+        << "This is fig2sxd version 0.17. (C) 2003-2007 Alexander Bürger."
         << endl;
 }
 
@@ -465,14 +466,14 @@ int try_catched_main( int argc, char* argv[] )
 
     bool dotfig=false, dotxfig=false;
     string figfilename;
-    int ffnl=0;
+    unsigned int ffnl=0;
     if( argc>=2 ) {
         figfilename = argv[1];
         ffnl = figfilename.length();
     }
     if( argc==2 ) {
-        dotfig  = ( ffnl>4 && figfilename.rfind( ".fig")!=string::npos );
-        dotxfig = ( ffnl>5 && figfilename.rfind(".xfig")!=string::npos );
+        dotfig  = ( ffnl>4 && figfilename.rfind( ".fig")+4==ffnl );
+        dotxfig = ( ffnl>5 && figfilename.rfind(".xfig")+5==ffnl );
     }
     if( argc != 3 && !dotfig && !dotxfig ) {
         usage( argv[0], true );
@@ -481,13 +482,15 @@ int try_catched_main( int argc, char* argv[] )
 
     initcolors();
 
-    // read xfig file
-    const bool read_stdin = (strcmp(argv[1],"-")==0);
-    ifstream* infile = read_stdin ? 0 : new ifstream( argv[1] );
-    read_file( read_stdin ? cin : *infile );
-    delete infile;
+    // read xfig file / stdin
+    if( figfilename != "-" ) {
+        ifstream infile( figfilename.c_str() );
+        read_file( infile );
+    } else {
+        read_file( std::cin );
+    }
 
-    // write sxd file
+    // write sxd file / stdout
     string sxd;
     if( dotfig )
         sxd = figfilename.substr(0,ffnl-4)+".sxd";
@@ -495,8 +498,14 @@ int try_catched_main( int argc, char* argv[] )
         sxd = figfilename.substr(0,ffnl-5)+".sxd";
     else
         sxd = argv[2];
-    ofstream sxdfile( sxd.c_str(), ios::binary );
-    write_file( sxdfile );
+    if( sxd.empty() )
+        throw string( "output filename is empty" );
+    if( sxd != "-" ) {
+        ofstream sxdfile( sxd.c_str(), ios::binary );
+        write_file( sxdfile );
+    } else {
+        write_file( std::cout );
+    }
     return 0;
 }
 
