@@ -2,7 +2,7 @@
 
 // fixg2sxd - a utility to convert fig to sxd format
 
-// Copyright (C) 2003-2006 Alexander Bürger, acfb@users.sourceforge.net
+// Copyright (C) 2003-2007 Alexander Bürger, acfb@users.sourceforge.net
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -20,6 +20,7 @@
 
 #include "zipwrite.h"
 
+#include <cstdlib>
 #include <iostream>
 #include <streambuf>
 
@@ -156,8 +157,6 @@ ZipWriter::~ZipWriter()
     write4( zip, rel_offset_central_dir );
     // .ZIP file comment length -- comment is empty (2 bytes)
     write2( zip, 0 );
-
-    delete zipfile;
 }
 
 ostream& ZipWriter::GetStream( const char* name )
@@ -291,7 +290,8 @@ int main( int argc, char* argv[] )
         exit( -1 );
     }
 
-    ZipWriter zw( argv[1] );
+    std::ofstream zipout( argv[1] );
+    ZipWriter zw( zipout );
     for( int f = 2; f<argc; ++f ) {
         ifstream file( argv[f], ios::binary );
         if( !file ) {
