@@ -2,7 +2,7 @@
 
 // fixg2sxd - a utility to convert fig to sxd format
 
-// Copyright (C) 2003-2006 Alexander Bürger, acfb@users.sourceforge.net
+// Copyright (C) 2003-2007 Alexander Bürger, acfb@users.sourceforge.net
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -43,21 +43,13 @@ class ZipWriter {
 
     typedef std::vector<fileinfo> fileinfos_t;
     fileinfos_t fileinfos;
-    std::ofstream*const zipfile;
     std::ostream& zip;
     std::ostream* out;
     z_stream zs;
     char cbuf[32768];
 public:
-    ZipWriter( const char* filename )
-        : zipfile( new std::ofstream( filename, std::ios::binary ) ),
-          zip( *zipfile ),
-          out(0)
-        { }
-
     ZipWriter( std::ostream& z )
-        : zipfile( 0 ),
-          zip( z ),
+        : zip( z ),
           out(0)
         { }
 
